summaryrefslogtreecommitdiff
path: root/src/Models/LogEntry.php
diff options
context:
space:
mode:
authorIgor Scheller <igor.scheller@igorshp.de>2019-11-06 13:43:57 +0100
committerIgor Scheller <igor.scheller@igorshp.de>2019-11-06 13:43:57 +0100
commit8b5b9e2c65193171a12bf99a8df860a66e6900a5 (patch)
treeeed7c815dfa7f6b034dff3e758e6578d26e3d81e /src/Models/LogEntry.php
parent2cce967eb09edd6ef35238c68f8ff5ed2348f5fd (diff)
src/: Formatting, doc block hints and cleanup
Diffstat (limited to 'src/Models/LogEntry.php')
-rw-r--r--src/Models/LogEntry.php18
1 files changed, 10 insertions, 8 deletions
diff --git a/src/Models/LogEntry.php b/src/Models/LogEntry.php
index db427eb9..53f72b65 100644
--- a/src/Models/LogEntry.php
+++ b/src/Models/LogEntry.php
@@ -2,19 +2,21 @@
namespace Engelsystem\Models;
+use Carbon\Carbon;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Collection;
+use Illuminate\Database\Query\Builder as QueryBuilder;
/**
- * @property int $id
- * @property string $level
- * @property string $message
- * @property \Carbon\Carbon|null $created_at
+ * @property int $id
+ * @property string $level
+ * @property string $message
+ * @property Carbon|null $created_at
*
* @method static \Illuminate\Database\Query\Builder|\Engelsystem\Models\LogEntry[] whereId($value)
* @method static \Illuminate\Database\Query\Builder|\Engelsystem\Models\LogEntry[] whereLevel($value)
* @method static \Illuminate\Database\Query\Builder|\Engelsystem\Models\LogEntry[] whereMessage($value)
* @method static \Illuminate\Database\Query\Builder|\Engelsystem\Models\LogEntry[] whereCreatedAt($value)
*/
class LogEntry extends BaseModel
{
@@ -2,19 +2,21 @@
*
- * @method static \Illuminate\Database\Query\Builder|\Engelsystem\Models\LogEntry[] whereId($value)
- * @method static \Illuminate\Database\Query\Builder|\Engelsystem\Models\LogEntry[] whereLevel($value)
- * @method static \Illuminate\Database\Query\Builder|\Engelsystem\Models\LogEntry[] whereMessage($value)
- * @method static \Illuminate\Database\Query\Builder|\Engelsystem\Models\LogEntry[] whereCreatedAt($value)
+ * @method static QueryBuilder|LogEntry[] whereId($value)
+ * @method static QueryBuilder|LogEntry[] whereLevel($value)
+ * @method static QueryBuilder|LogEntry[] whereMessage($value)
+ * @method static QueryBuilder|LogEntry[] whereCreatedAt($value)
*/
class LogEntry extends BaseModel